//
// gets options from the command line
//

#include "mkevals.h"
#include "errors.h"

#ifdef __GLIBC__           // getopt_long is in glibc on linux
#include <getopt.h>        // getopt.h may not exist on SunOs etc
#endif

void get_opts(int argc, char** argv, misc* mp)
{
    extern int opterr;
    int i;
    string pgname = basename(argv[0]);
    string::size_type n = pgname.rfind(".exe");
    if (n < string::npos) {
        pgname.erase(n);
    }

#ifdef __GLIBC__
    int opt_index = 0;
    static struct option long_options[] = {
        {"help", 0, 0, 'h'},
        {"old", 0, 0, 'o'},
        {"plus", 0, 0, 'p'},
        {"rank", 0, 0, 'r'},
        {"version", 0, 0, 'v'},
        {"upgrade", 0, 0, 'u'},
        {"debug", 0, 0, 'd'},
        {0, 0, 0, 0}
    };
#endif

    opterr = yes;

#ifdef __GLIBC__
    while ((i = getopt_long( argc, argv, "dhopruv",
            long_options, &opt_index)) != -1 ) {
#else
    while ((i = getopt( argc, argv, "dhopruv")) != -1){
#endif
        if (i == -1)
            break;

        switch (i) {
            case 'h':       // display help file
                prn_info(argv);
                exit(0);
                break;
            case 'o':       // use old style class rosters
                mp->old = yes;
                break;
            case 'p':       // plus: distinguish A+,A,A-,B+,B,B-, etc grades
                mp->plus = yes;
                break;
            case 'r':       // rank: create name list ranked by category
                mp->rank = yes;
                break;
            case 'u':       // upgrade: discount early low midterm score
                mp->upgrade = yes;
                break;
            case 'v':       // print version number
 //               cerr.setf(ios::showpoint);
 //               cerr.precision(2);
                cerr << pgname << " version " << version << "\n";
                exit(0);
                break;
            case 'd':       // shows details of scoring process
                mp->debug = on;
                break;
            case '?':       // for unrecognized option
                prn_usage(argv);
                exit( 1 );
        }
    }
}
