// takes header line and forms the full name of the student, by
// extracting first the last name, then the first and middle
// names (trimming any space chars from the fronts and ends of
// those strings), then reconstrucing the full name string, and
// adding spaces or subtracting chars to make the full name
// string exactly 31 chars in length.
//
// this depends pretty heavily on format of header lines in the
// class roster supplied by the registrar, in particular on the
// number of commas (or fields) in the header line.
//
// returns full name as on header (adjusted to the desired length).
//
// this function was last modified on Sat Jul  9, 2005, with the
// functions "trimspace()" and "pad_space()" being added to the
// code.

#include "mkevals.h"

string getfullname(misc* mp, string& header)
{
    const char comma = ',';               // registrar's field separator
    const char space = ' ';
    string s = header;                    // make copy of header line
    s.erase(0, s.find(comma)+1);          // trim front "&&&&,"

    string lname = s.substr(0, s.find(comma));   // get last name
    trimspace(lname);                     // trim space from lname
    s.erase(0, s.find(comma)+1);          // erase last name from front

    string fname = s.substr(0, s.find(comma));   // get first name
    trimspace(fname);                     // trim space from fname
    s.erase(0, s.find(comma)+1);          // erase first name from front

    if (!mp->old) {                       // we're using new style headers
        string mname = s.substr(0, s.find(comma));   // get middle name
        if (isdigit(mname.c_str()[0])) {  // looking at ID field?
            err("Found an old style header line (missing a comma?) at ",
            lname,
            ".\n   (Try adding a comma between the first and middle names,"
            "\n   or try using the \"-o\" or \"--old\" option to mkevals.)");
        }
        trimspace(mname);                 // trim space from mname
        string name = lname + comma + space + fname + space + mname;
        name = pad_space(name, 31);       // adds spaces or subtracts chars
                                          // to make name 31 chars long
        return name;
    }
    else {                                // we're using old style headers
        string name = lname + comma + space + fname;
        name = pad_space(name, 31);       // adds spaces or subtracts chars
                                          // to make name 31 chars long
        return name;
    }
}
